==> haskell-type-errors-pretty-0.0.1.1-75-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-type-errors-pretty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 type-errors-pretty
version:              0.0.1.1
visibility:           public
id:                   type-errors-pretty-0.0.1.1-6fFNlnzwOMoIT2AVVqsHhx
key:                  type-errors-pretty-0.0.1.1-6fFNlnzwOMoIT2AVVqsHhx
license:              MPL-2.0
copyright:            2019-2020 Dmitrii Kovanikov
maintainer:           Dmitrii Kovanikov <kovanikov@gmail.com>
author:               Dmitrii Kovanikov
homepage:             https://github.com/chshersh/type-errors-pretty
synopsis:             Combinators for writing pretty type errors easily
description:
    This library provides replacements for the @ErrorMessage@ constructors to
    write the text of custom error messages easily.

category:             Types, Type Errors
abi:                  83ae0ac65478f95b1ca1a2691fe90d01
exposed:              True
exposed-modules:      Type.Errors.Pretty
import-dirs:          /usr/lib/ghc-8.10.5/site-local/type-errors-pretty-0.0.1.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/type-errors-pretty-0.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.5/type-errors-pretty-0.0.1.1

hs-libraries:         HStype-errors-pretty-0.0.1.1-6fFNlnzwOMoIT2AVVqsHhx
depends:              base-4.14.2.0
haddock-interfaces:
    /usr/share/doc/haskell-type-errors-pretty/html/type-errors-pretty.haddock

haddock-html:         /usr/share/doc/haskell-type-errors-pretty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-type-errors-pretty-0.0.1.1-76-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-type-errors-pretty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 type-errors-pretty
version:              0.0.1.1
visibility:           public
id:                   type-errors-pretty-0.0.1.1-12AiUnri6FF3QG6I7GA5dA
key:                  type-errors-pretty-0.0.1.1-12AiUnri6FF3QG6I7GA5dA
license:              MPL-2.0
copyright:            2019-2020 Dmitrii Kovanikov
maintainer:           Dmitrii Kovanikov <kovanikov@gmail.com>
author:               Dmitrii Kovanikov
homepage:             https://github.com/chshersh/type-errors-pretty
synopsis:             Combinators for writing pretty type errors easily
description:
    This library provides replacements for the @ErrorMessage@ constructors to
    write the text of custom error messages easily.

category:             Types, Type Errors
abi:                  a1c09331c24e0984b79615bfccf75cfc
exposed:              True
exposed-modules:      Type.Errors.Pretty
import-dirs:          /usr/lib/ghc-9.0.1/site-local/type-errors-pretty-0.0.1.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/type-errors-pretty-0.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/type-errors-pretty-0.0.1.1

hs-libraries:         HStype-errors-pretty-0.0.1.1-12AiUnri6FF3QG6I7GA5dA
depends:              base-4.15.0.0
haddock-interfaces:
    /usr/share/doc/haskell-type-errors-pretty/html/type-errors-pretty.haddock

haddock-html:         /usr/share/doc/haskell-type-errors-pretty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
